@@ -1,6 +1,6 @@
 package Mongoose::Class;
-BEGIN {
-  $Mongoose::Class::VERSION = '0.10';
+{
+  $Mongoose::Class::VERSION = '0.11';
 }
 use Moose ();
 use Moose::Exporter;
@@ -29,24 +29,30 @@ sub belongs_to {
     my $meta = shift;
     my $name = shift;
     my %options;
-    if ( scalar @_ == 1 ) {
-        $options{isa} = shift;
-        $options{is}  = 'rw';
-    }
-    else { %options = @_; }
+    if   ( scalar @_ == 1 ) { $options{isa} = shift; }
+    else                    { %options      = @_; }
+    $options{is}  ||= 'rw';
+    %options = ( %options, @_ ) if @_;
 
-    $meta->add_attribute( $name, %options, );
+    $meta->add_attribute( $name, %options );
 }
 
 sub has_one {
     my $meta = shift;
     my $name = shift;
     my %options;
-    if ( scalar @_ == 1 ) {
+    if ( @_ > 0 && @_ % 2 ) {
         $options{isa} = shift;
         $options{is}  = 'rw';
+        if( @_ > 1 ) {  # allow: has_one 'att' => 'Str', required=>1;
+            %options = ( %options, @_ );
+        }
+    }
+    else {
+        %options = @_;
+        $options{isa} ||= 'Any';
+        $options{is}  ||= 'rw';
     }
-    else { %options = @_; }
 
     $meta->add_attribute( $name, %options, );
 }
@@ -57,7 +63,7 @@ Mongoose::Class - sugary Mongoose-oriented replacement for Moose
 
 =head1 VERSION
 
-version 0.10
+version 0.11
 
 =head1 SYNOPSIS
 
@@ -65,10 +71,10 @@ version 0.10
     use Mongoose::Class; # uses Moose for you
     with 'Mongoose::Document';
 
-    has 'name' => ( is=>'rw', isa=>'Str' );
-    has_many 'siblings' => ( is=>'rw', isa=>'Person' );
-    belongs_to 'club' => ( is=>'rw', isa=>'Club' );
-    has_one 'father' => ( is=>'rw', isa=>'Person' );
+    has 'name'          => ( is => 'rw', isa => 'Str' );
+    has_many 'siblings' => ( is => 'rw', isa => 'Person' );
+    belongs_to 'club'   => ( is => 'rw', isa => 'Club' );
+    has_one 'father'    => ( is => 'rw', isa => 'Person' );
 
 =head1 DESCRIPTION
 
@@ -89,11 +95,17 @@ by self-documenting your class.
 
 =head2 has_one
 
-Does nothing. It's the same as using C<has>.
+Wrapper around Moose's own C<has>, but allows
+for a shorter syntax:
+
+    has_one 'name';            # isa=>'Any', is=>'rw' added
+    has_one 'age' => 'Num';    # is=>'rw' added
+    has_one 'age' => 'Num', default=>99;
 
 =head2 belongs_to
 
-Does nothing. It's the same as using C<has>.
+It's the same as using C<has_one> from above. 
+It exists to improve your code expressiveness.
 
 =head2 has_many
 
@@ -105,7 +117,7 @@ This:
 
     # or
 
-    has_manu 'employees' => 'Employee';
+    has_many 'employees' => 'Employee';
 
 Becomes this:
 
@@ -117,4 +129,4 @@ Becomes this:
     
 =cut
 
-1;
\ No newline at end of file
+1;
